<?php

namespace Drupal\cryptophoto\Controller;

require_once("lib/CryptoPhotoUtils.php");

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

class CryptoPhotoTestSettingsController extends ControllerBase {
  public $request;

  public function __construct(RequestStack $request) {
    $this->request = $request;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /*
   * AJAX CryptoPhoto test
   */
  public function cp_test() {
    $req = $this->request->getCurrentRequest();

    // get CryptoPhoto setup from user input
    $privatekey = $req->get('privatekey');
    $publickey = $req->get('publickey');
    $salt = $req->get('salt');
    $server = $req->get('server');

    // test result
    $result = "";
    
    // setup server if needed
    if (!$server) $server = "https://cryptophoto.com";

    // test non-empty input
    if ($privatekey && $publickey && $salt) {
        // new CryptoPhoto instance
        $cp = new \CryptoPhotoUtils($server, $privatekey, $publickey, md5($salt));
        
        // attempt to start a new session
        $session = $cp->start_session($_SERVER['REMOTE_ADDR']);

        // test if new session started successfully
        if ($session[0] == TRUE) {
            $result = "success";
        } else {        
            // something went wrong, look for the reason why
            if ($session[1] == "incorrect-timestamp") {
                $result = "timestamp";
            } else if ($session[1] == "inexistent-provider") {
                $result = "inexistent-provider";
            } else if (strpos($session[1],"ip-not-allowed") !== false) {
                $result = "ip " . $session[2];
            } else if ($session[1] == "incorrect-signature" || $session[1] == "incorrect-api-request") {
                $result = "invalid";
            } else $result = "other";
        }
    } else {
        // one or more empty fields
        $result = "empty";
    }

    // send back the result as text/plain
    header("Content-type: text/plain");
    print $result;

    exit;
  }

}

?>
