<?php

namespace Drupal\cryptophoto\Storage;

use \Drupal\Core\Database\Database;

/*
 * CryptoPhoto Sotrage
 */
class CryptoPhotoStorage {
    private $db;

    public function __construct() {
        // get database connection
        $this->db = \Drupal\Core\Database\Database::getConnection();
    }

    /*
     * Get CryptoPhoto users
     * We apply filter and pagination
     */
    public function getUsers($filter = '') {
        $query = $this->db->select('cryptophoto_users', 'c');
        $query->join('users_field_data', 'u', 'c.uid = u.uid');
        $query->fields('c', array('enabled', 'override'));
        $query->fields('u');
        $query->orderBy('uid', 'ASC');

        if ($filter) {
            $query->condition(db_or()->condition('u.name', "%$filter%", 'LIKE')->condition('u.mail', "%$filter%", 'LIKE'));
        }

        $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(20);
        $result = $pager->execute()->fetchAllAssoc('uid');

        return $result;
    }

    /*
     * Check for user setup
     */
    public function exists($uid) {
        $result = $this->db->query('SELECT 1 FROM {cryptophoto_users} WHERE uid = :uid', array(':uid' => $uid))->fetchField();
        return $result ? 1 : 0;
    }

    /*
     * Check fro admin override
     */
    public function getOverride($uid) {
        $result = $this->db->query('SELECT override FROM {cryptophoto_users} WHERE uid = :uid', array(':uid' => $uid))->fetchField();
        return $result ? 1 : 0;
    }

    /*
     * Set admin override
     */
    public function setOverride($uid, $override) {
        if ($this->exists($uid)) {
            $this->db->update('cryptophoto_users')
                     ->fields(array(
                        'override' => $override ? 1 : 0
                     ))
                     ->condition('uid', $uid, '=')
                     ->execute();
        }
    }

    /*
     * Get CryptoPhoto enabled status
     */
    public function getStatus($uid) {
        $result = $this->db->query('SELECT enabled FROM {cryptophoto_users} WHERE uid = :uid', array(':uid' => $uid))->fetchField();
        return $result ? 1 : 0;
    }

    /*
     * Get CryptoPhoto effective enabled status (includes override + reset)
     */
    public function getEffectiveStatus($uid) {
        $result = $this->db->query('SELECT uid, enabled, override FROM {cryptophoto_users} WHERE uid = :uid', array(':uid' => $uid))->fetchAll();

        if ($result == null) return 0;

        $result = $result[0];

        error_log("RESULT = " . print_r($result,1));

        if ($result) {
            if ($result->override) {
                $this->db->update('cryptophoto_users')
                         ->fields(array(
                            'override' => 0
                         ))
                         ->condition('uid', $uid, '=')
                         ->execute();
                $result = 0;
            } else {
                $result = $result->enabled;
            }
        } else {
            $result = 0;
        }

        return $result;
    }

    /*
     * Set CryptoPhoto enabled status
     */
    public function setStatus($uid, $enabled) {
        if ($this->exists($uid)) {
            $this->db->update('cryptophoto_users')
                     ->fields(array(
                        'enabled' => $enabled ? 1 : 0
                     ))
                     ->condition('uid', $uid, '=')
                     ->execute();
        } else {
            $this->db->insert('cryptophoto_users')
                     ->fields(array(
                        'uid' => $uid,
                        'enabled' => $enabled
                     ))
                     ->execute();
        }
    }

    /*
     * Store CryptoPhoto authentication session
     */
    public function addAuth($sid, $uid, $redirect_url) {
        $this->db->insert('cryptophoto_logins')
                 ->fields(array(
                    'sid' => $sid,
                    'uid' => $uid,
                    'redirect_url' => $redirect_url,
                    'time' => date("Y-m-d H:i:s", time())
                 ))
                 ->execute();
    }

    /*
     * Get CryptoPhoto authentication session
     */
    public function getAuth($sid) {
        $result = $this->db->query('SELECT uid, redirect_url, time FROM {cryptophoto_logins} WHERE sid = :sid', array(':sid' => $sid))->fetchAll();

        if ($result) $result = $result[0];

        return $result;
    }

    /*
     * Remove CryptoPhoto authentication session
     */
    public function delAuth($sid) {
        $this->db->delete('cryptophoto_logins')
                 ->condition('sid', $sid, '=')
                 ->execute();
    }
}

?>
